import qs from 'qs';
// import { async } from 'q';

const baseUri = "http://127.0.0.1:8000";
const processResponse = (promise) => {
    return new Promise((resolve, reject) => {
        promise.then(ret => {
            if (typeof (ret['code']) != 'undefined') {
                if (ret.code != 0) {
                    reject(new Error(ret.message));
                    return;
                }
            }
            resolve(ret);
        }).catch(err => {
            reject(err);
        })
    })
}

class Api {
    constructor(baseUri) {
        this.baseUri = baseUri;
    }

    $getUrl(url) {
        return this.baseUri + url;
    }

    buildToken(data) {
        if(!data) data= {};
        if (!data['token']) {
            let token = localStorage.getItem('gg_user_token');
            if (token) {
                data['token'] = token;
            }
        }
        return data;
    }

    async get(url, data = null) {
        data = this.buildToken(data)
        if (data) {
            url += url.indexOf('?') == -1 ? '?' : '&'
            url += qs.stringify(data);
        }
        const resp = await fetch(this.$getUrl(url));
        return processResponse(resp.json());
    }

    async post(url, data) {
        data = this.buildToken(data)
        const resp = await fetch(this.$getUrl(url), {
            body: qs.stringify(data),
            method: 'post',
            headers: {
                'Content-Type': 'application/x-www-form-urlencoded'
            }
        });
        return processResponse(resp.json());
    }
}

const http = new Api(baseUri);
export default {
    http,
    shop: new Api(baseUri)
};
